import greenfoot.*;

import java.util.List;
import java.util.ArrayList;

/**
 * Animal. This is the base class for all animals. In addition to the standard Actor
 * methods, it provides the ability to move and turn.
 */

public class Animal extends Actor
{
    /////////////////// Methods /////////////////////  
    /**
     * Turns the given number of degrees to the right (that is, clockwise).
     * @param angle The number of degrees this animal turns to the right.
     */
    public void turn(int angle)
    {
        setRotation(getRotation() + angle);
    }
    

    /**
     * Moves forward in the current direction as determined from current rotation.
     */
    public void move(double animalSpeed)
    {
        if (atWorldEdge( )) {
            turn(10); //when hits world edge, will turn 17 degrees.
            
        }
            double angle = Math.toRadians( getRotation() );
            int x = (int) Math.round(getX() + Math.cos(angle) * animalSpeed);
            int y = (int) Math.round(getY() + Math.sin(angle) * animalSpeed);
            setLocation(x, y);
    }
    
    
    public void turnRandom()
    {
        if(Greenfoot.getRandomNumber(100) < 10)
        {
           turn(Greenfoot.getRandomNumber(90) - 45); 
        }
    }
    
    /**
     * Tests if this animal is close to one of the edges of the world. 
     * @return True if at the edge, false otherwise.
     * Note that 20 pixels is the margin for "touching" an edge. 
     */
    public boolean atWorldEdge()
    {
        //If current x is too close to 0 or too close to world's width
        if(getX() < 20 || getX() > getWorld().getWidth() - 20) {
            return true; //return value is true and method execution stops here.
        }
        //If condition above was false 
        //AND current y is too close to 0 or too close to world's height
        if(getY() < 20 || getY() > getWorld().getHeight() - 20) {
            return true; //return value is true and method execution stops here.
        }

        //None of the conditions above was true. 
        return false;//return value is false and method execution stops here.
    }
    
    
    /**
     * Tests if this animal overlaps with another object of given class.
     * @param clss The class of the object that might be at the location this animal is at.
     * @return True if this animal overlaps with another object of given class.
     * False if there is no such object at the same location.
     */
    public boolean canSee(Class clss)
    {
        Actor actor = getOneObjectAtOffset(0, 0, clss);
        return actor != null;        
    }

    /**
     * Removes an object of the given class if there is one at the location this animal is at.
     * @param - The class of the object that might be at the location this animal is at.
     */
    public void eat(Class clss)
    {
        Actor actor = getOneObjectAtOffset(0, 0, clss);
        if(actor != null) {
            getWorld().removeObject(actor);
        }
    }
    
    public void person()
    {
       setImage("person.png");
    }
        
    public void ant()
    {
        setImage("ant.png");
    }
    
    public void bigAnt()
    {
        setImage("bigant.png");
    }
    public void fly()
    {
        setImage("fly.png");
    }
    public void spider()
    {
        setImage("spider.png");
    }
    public void bee()
    {
        setImage("bee.png");
    }
    public void frog()
    {
        setImage("frog.png");
    }
    public void lizard()
    {
        setImage("lizard.png");
    }
    public void snake()
    {
        setImage("snake.png");
    }
    public void bigSnake()
    {
        setImage("bigsnake.png");
    }
    public void aligator()
    {
        setImage("alligator.png");
    }
    public void polarBear()
    {
       setImage("polarbear.png");
    }
    
}
